require 'gradesfirst/command'

module GradesFirst

  # Implemenation of a Thor command for enhancing git branch to include
  # PivotalTracker information such as the story state, name and url.
  class BranchCommand < GradesFirst::Command

    # Description of the gf branch Thor command that will be used in the
    # commandline help.
    def self.description
      'List git branches with related PivotalTracker story information.'
    end

    def initialize
      @enhanced_branches = []
    end

    # Performs the gf branch Thor command.
    def execute
      git_response = git_branch
      git_response.each_line do |branch|
        @enhanced_branches << enhanced_branch(branch.rstrip)
      end
      nil
    end

    # Output response of the gf branch Thor command that contains the
    # PivotalTracker enhanced branch names.
    def response
      @enhanced_branches.join("\n") + "\n"
    end

    private

    def enhanced_branch(branch)
      story = find_story_by_branch(branch)
      if story
        status = story['current_state'].capitalize
        "#{branch} [#{status}] #{story['name']} (#{story['url']})"
      else
        branch
      end
    end

    def find_story_by_branch(branch)
      if story_id(branch)
        PivotalTracker.stories[story_id(branch)].get
      else
        nil
      end
    end

    def git_branch
      `git branch`
    end

  end
end
