require 'gradesfirst'
require 'gradesfirst/config'

module GradesFirst

  # Base class for all command objects
  class Command

    private

    # Retrieves the current git branch
    def current_branch
      `git rev-parse --abbrev-ref HEAD`
    end

    # Retrieves the current story
    def current_story
      PivotalTracker.stories[story_id].get
    end

    # Extracts a PivotalTracker story id from a branch if one is present
    def story_id(branch = current_branch)
      if branch =~ /[0-9]+$/
        branch.match(/[0-9]+$/)[0]
      else
        nil
      end
    end

    # Configuration for the current project
    def config
      @configuration ||= GradesFirst::Config.new
    end

    # The beginning date of a sprint
    def day_zero
      config.day_zero
    end
  end
end
