require 'gradesfirst/command'

module GradesFirst

  # Implementation of a Thor command for creating a git commit message that
  # already includes the information from the related PivotalTracker story
  # associated with the current branch.
  class CommitMessageCommand < GradesFirst::Command

    # Description of the gf commit-message Thor command that well be usewd in
    # the commandline help.
    def self.description
      'Generate a git commit message in the standard format.'
    end

    # Performs the gf commit-message Thor command.
    def execute
      @story = current_story
    end

    # Output response of the gf commit-message Thor command in the standard
    # format.
    def response
      if @story.nil?
        ''
      else
        message = [
          "",
          "",
          constrain_line_length(@story['name'], 72),
          @story['url']
        ]
        message.join("\n") + "\n"
      end
    end

    private

    def constrain_line_length(string, length)
      line_break_characters = '(?:[ .!?,\-();:\[\]]|$)'
      lines = /.{,#{length.to_i}}#{line_break_characters}/

      string.
        scan(lines).
        map { |line| line.strip }.
        select { |line| line.length > 0 }.
        join("\n")
    end
  end
end
