require 'dotenv'

module GradesFirst
  class Config
    def initialize
      if GradesFirst::Config.load_paths.any?{ |f| File.exist?(f) }
        Dotenv.load(*GradesFirst::Config.load_paths)
      else
        puts <<-MESSAGE
The configuration file is missing and should be found in one of the
following locations:

#{GradesFirst::Config.load_paths.join('\n')}

See "gf help <command>" for details on configuration settings.
        MESSAGE
      end
    end

    def self.load_paths
      @@load_paths ||= [".env.gf", "#{Dir.home}/.env.gf", ".env.gf.master"]
    end

    def self.load_paths=(paths)
      @@load_paths = paths
    end

    def code_talkers
      ENV["GF_CODE_TALKERS"].to_s.split("|")
    end

    def day_zero
      if ENV["GF_DAY_ZERO"].nil?
        Time.now
      else
        Time.parse(ENV["GF_DAY_ZERO"])
      end
    end

    def developers
      ENV["GF_DEVELOPERS"].to_s.split("|")
    end
  end
end
