require 'gradesfirst/task_command'

module GradesFirst

  # Implementation of a Thor command for adding tasks to PivotalTracker stories.
  class TaskAddCommand < GradesFirst::TaskCommand
    # Description of the "gf task add" Thor command that will be used in
    # the commandline help.
    def self.description
      'Add a task to a PivotalTracker story.'
    end

    # Performs the gf task add Thor command.
    def execute(description)
      @story = current_story
      if @story
        @success = task_add(@story, description)
      end
    end

    # Generates the command line output response.  The output of the task add
    # command is a completion status message which may be followed by the new
    # list of tasks if the task was added successfully.
    def response
      task_action_response(@story, @success)
    end

    private

    def story_error_message
      'Tasks cannot be created for this branch.'
    end

    def task_add(story, description)
      PivotalTracker.
        projects[story['project_id']].
        stories[story['id']].
        tasks.
        post(description: description)
    end

    def task_error_message
      'Creation of the task failed.'
    end

    def task_success_message
      'Task was successfully added.'
    end
  end

end
