require 'gradesfirst/command'

module GradesFirst
  class TaskCommand < GradesFirst::Command
    private

    def get_task_id_by_position(story, position)
      task = get_task_by_position(story, position)
      task['id'] if task
    end

    def get_task_by_position(story, position)
      get_tasks(story).find { |t| t['position'] == position.to_i }
    end

    def get_tasks(story)
      PivotalTracker.
        projects[story['project_id']].
        stories[story['id']].
        tasks.
        get
    end

    def position(task)
      task['position'].to_s.rjust(2)
    end

    def story_line(story)
      "#{TAB}#{story['name']} (#{story['url']})\n\n"
    end

    # Generates the commandline output response for actions taken on tasks like
    # add and delete.
    def task_action_response(story, success)
      if story.nil?
        story_error_message
      elsif !success
        task_error_message
      else
        tasks = get_tasks(story)
        [
          TAB + task_success_message,
          task_list_response(story, tasks)
        ].join("\n\n")
      end
    end

    def task_list_response(story, tasks)
      task_list = tasks.map do |t|
        "#{TAB}#{position(t)}. [#{t["complete"] ? 'X' : ' '}] #{t["description"]}"
      end
      story_line(story) + task_list.join("\n") + "\n"
    end
  end
end
