require 'gradesfirst/task_command'

module GradesFirst

  # Implementation of a Thor command for deleting tasks from PivotalTracker
  # stories.
  class TaskDeleteCommand < GradesFirst::TaskCommand
    # Description of the "gf task delete" Thor command that will be used in
    # the commandline help.
    def self.description
      'Delete a task from a PivotalTracker story.'
    end

    # Performs the gf task delete POSITION Thor command.
    def execute(position)
      @story = current_story
      if @story
        task_id = get_task_id_by_position(@story, position)
        if task_id
          @success = task_delete(@story, task_id)
        else
          @task_position_invalid = true
        end
      end
    end

    # Generates the command line output response.  The output of the task delete
    # command is a completion status message which may be followed by the new
    # list of tasks if the task was deleted successfully.
    def response
      if @task_position_invalid
        position_invalid_message
      else
        task_action_response(@story, @success)
      end
    end

    private

    def position_invalid_message
      'Task position given does not exist.'
    end

    def story_error_message
      'Tasks cannot be deleted for this branch.'
    end

    def task_delete(story, task_id)
      PivotalTracker.
        projects[story['project_id']].
        stories[story['id']].
        tasks[task_id].
        delete
    end

    def task_error_message
      'Deletion of the task failed.'
    end

    def task_success_message
      'Task was successfully deleted.'
    end
  end
end
