require 'gradesfirst/task_command'

module GradesFirst

  # Implementation of a Thor command for listing tasks related to a story.
  class TaskListCommand < GradesFirst::TaskCommand

    # Description of the gf task list Thor command that will be used in the
    # command line help.
    def self.description
      'List the tasks related to a PivotalTracker story.'
    end

    # Performs the gf task list Thor command.
    def execute
      @story = current_story
      if @story
        @tasks = get_tasks(@story)
      end
    end

    # Generates the comand line output response.  The output of the task command
    # is a list of the tasks associated with the PivotalTracker story associated
    # with the current branch.
    def response
      if @tasks.nil?
        story_error_message
      else
        task_list_response(@story, @tasks)
      end
    end

    private

    def story_error_message
      'Tasks cannot be retrieved for this branch.'
    end

  end
end
