require 'gradesfirst/task_command'

module GradesFirst

  # Implementation of a Thor command for moving tasks on a PivotalTracker story
  # from one priority position to another in the list.
  class TaskMoveCommand < GradesFirst::TaskCommand
    # Description of the "gf task move" Thor command that will be sued in the
    # commandline help.
    def self.description
      'Move a task to a new position in the list for a PivotalTracker story.'
    end

    # Performs the gf task move Thor command.
    def execute(from, to)
      @story = current_story
      if @story
        task_id = get_task_id_by_position(@story, from)
        if task_id
          @success = task_move(@story, task_id, to)
        else
          @task_position_invalid = true
        end
      end
    end

    # Generates the command line output response. The output of the task move
    # command is a completion status message which may be followed by the new
    # list of tasks if the task was moved successfully.
    def response
      if @task_position_invalid
        position_invalid_message
      else
        task_action_response(@story, @success)
      end
    end

    private

    def position_invalid_message
      'Task "from" position given does not exist.'
    end

    def story_error_message
      'Tasks cannnot be moved for this branch.'
    end

    def task_error_message
      'Moving the task failed.'
    end

    def task_move(story, task_id, to)
      PivotalTracker.
        projects[story['project_id']].
        stories[story['id']].
        tasks[task_id].
        put(position: to.to_i)
    end

    def task_success_message
      'Task was successfully moved.'
    end
  end
end
