require 'gradesfirst/task_command'

module GradesFirst

  # Implementation of a Thor command for toggling whether or not a task is
  # complete.
  class TaskToggleCommand < GradesFirst::TaskCommand
    # Description of the "gf task toggle" Thor command that will be used in
    # the commandline help.
    def self.description
      'Toggle completion status of a PivotalTracker story task.'
    end

    # Performs the gf task toggle POSITION Thor command.
    def execute(position)
      @story = current_story
      if @story
        task = get_task_by_position(@story, position)
        if task
          @success = task_toggle(@story, task)
        else
          @task_position_invalid = true
        end
      end
    end

    # Generates the command line output response.  The output of the task toggle
    # command is a completion status message which may be followed by the new
    # list of tasks if the task was moved successfully.
    def response
      if @task_position_invalid
        position_invalid_message
      else
        task_action_response(@story, @success)
      end
    end

    private

    def position_invalid_message
      'Task position given does not exist.'
    end

    def story_error_message
      'Tasks cannot be toggled for this branch.'
    end

    def task_error_message
      'Toggling of the task completion status failed.'
    end

    def task_success_message
      'Task completion status was successfully toggled.'
    end

    def task_toggle(story, task)
      PivotalTracker.
        projects[story['project_id']].
        stories[story['id']].
        tasks[task['id']].
        put(complete: !task['complete'])
    end
  end

end
